Quick overview
==============

This project aims to allow for easy access to useful tools for photovoltaics.
It is a collection of utilities created by PV Performance Labs.
Users are encouraged to contribute to the project by submitting issues or pull
requests, so please, don't hesitate to reach out!

.. @Anton TODO, add more content as desired. Update index.rst with filenames.
